'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _CorePagination = require('./modules/CorePagination');

var _CorePagination2 = _interopRequireDefault(_CorePagination);

var _Prefix = require('./modules/Prefix');

var _Prefix2 = _interopRequireDefault(_Prefix);

var _isEqual = require('zent-utils/lodash/isEqual');

var _isEqual2 = _interopRequireDefault(_isEqual);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _React$PropTypes = _react2['default'].PropTypes,
    number = _React$PropTypes.number,
    func = _React$PropTypes.func,
    string = _React$PropTypes.string,
    oneOfType = _React$PropTypes.oneOfType;


var ZentPagination = _react2['default'].createClass({
  displayName: 'ZentPagination',

  propTypes: {
    className: string,
    prefix: string,
    current: number,
    totalItem: number,
    maxPageToShow: oneOfType([number, null]),
    pageSize: function pageSize(conf) {
      var pageSize = conf.pageSize;


      if (typeof pageSize === 'number') {
        if (pageSize < 0) {
          return new Error('pageSize必须大等于0');
        }
      } else if (Array.isArray(pageSize)) {
        var isAllNumber = void 0;
        if (pageSize.length === 0) {
          return new Error('pageSize的长度必须大于0');
        }

        isAllNumber = pageSize.every(function (item) {
          return typeof item === 'number' || (typeof item === 'undefined' ? 'undefined' : _typeof(item)) === 'object';
        });

        if (!isAllNumber) {
          return new Error('pageSize每一项必须是数字或对象');
        }
      } else {
        return new Error('pageSize只能是数字或数组');
      }
    },

    onChange: func
  },

  // 为了能本地动态修改每页个数，得自己缓存pageSize了
  getInitialState: function getInitialState() {
    var pageSize = this.parsePageSize(this.props.pageSize);
    var currentPageSize = this.getCurrentPageSize(pageSize);
    return {
      currentPageSize: currentPageSize
    };
  },


  /**
   * [getCurrentPageSize description]
   * @method getCurrentPageSize
   * @param  {[Array]}           ps [从parsePageSize返回的标准数组]
   * @return {[Number]}              [返回currentPageSize的数字值]
   */
  getCurrentPageSize: function getCurrentPageSize(ps) {
    for (var i = 0, len = ps.length; i < len; i++) {
      if (ps[i].isCurrent) {
        return ps[i].value;
      }
    }
    throw new Error('pageSize \u6570\u636E\u6709\u9519\u8BEF ' + ps);
  },
  parsePageSize: function parsePageSize(pageSize) {
    var ps = void 0;
    if (typeof pageSize === 'number') {
      ps = [{
        value: pageSize,
        isCurrent: true
      }];
    } else {
      var hasCurrent = void 0;

      ps = pageSize.map(function (item) {
        var tmp = void 0;
        if (typeof item === 'number') {
          tmp = {
            value: item
          };
        } else {
          tmp = item;
          if (tmp.isCurrent) {
            hasCurrent = true;
          }
        }
        return tmp;
      });

      if (!hasCurrent) {
        ps[0].isCurrent = true;
      }
    }

    return ps;
  },


  // BUG: 使用pager翻页之后会丢失原来的pageSize状态
  componentWillReceiveProps: function componentWillReceiveProps(nextProps) {
    if (!(0, _isEqual2['default'])(this.props.pageSize, nextProps.pageSize)) {
      var pageSize = this.parsePageSize(nextProps.pageSize);
      var currentPageSize = this.getCurrentPageSize(pageSize);
      this.setState({
        currentPageSize: currentPageSize
      });
    }
  },
  getDefaultProps: function getDefaultProps() {
    return {
      prefix: 'zent',
      pageSize: 10,
      className: ''
    };
  },
  setPageSize: function setPageSize(num) {
    this.setState({
      currentPageSize: parseInt(num, 10)
    });
  },
  render: function render() {
    // 如果传入的current小于1则进行修改
    var _props = this.props,
        totalItem = _props.totalItem,
        current = _props.current,
        pageSize = _props.pageSize,
        maxPageToShow = _props.maxPageToShow;

    pageSize = this.parsePageSize(pageSize);
    var currentPageSize = this.state.currentPageSize;


    var totalPage = Math.ceil(totalItem / currentPageSize);

    current = current > 1 ? current : 1; // 最小值限定
    current = current > totalPage ? totalPage : current; // 最大值限定

    return _react2['default'].createElement(
      'div',
      { className: this.props.prefix + '-pagination ' + this.props.className },
      _react2['default'].createElement(_Prefix2['default'], { pageSize: pageSize, currentPageSize: currentPageSize, totalItem: totalItem, setPageSize: this.setPageSize }),
      totalPage > 1 && _react2['default'].createElement(_CorePagination2['default'], { maxPageToShow: maxPageToShow, current: current, total: totalPage, onChange: this.props.onChange || function () {} })
    );
  }
});

exports['default'] = ZentPagination;
module.exports = exports['default'];