'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports['default'] = undefined;

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _class, _temp2;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _capitalize = require('zent-utils/lodash/capitalize');

var _capitalize2 = _interopRequireDefault(_capitalize);

var _uniq = require('zent-utils/lodash/uniq');

var _uniq2 = _interopRequireDefault(_uniq);

var _Trigger2 = require('./Trigger');

var _Trigger3 = _interopRequireDefault(_Trigger2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

// Hover识别的状态
var HoverState = {
  Init: 1,

  // 延迟等待中
  Pending: 2,

  Finish: 3
};

/**
 * 创建一个新state，每个state是一次性的，识别完成后需要创建一个新的state
 *
 * @param {string} name state的名称
 * @param {function} onFinish 识别成功时的回掉函数
 */
var makeState = function makeState(name, onFinish) {
  var initState = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : HoverState.Init;

  var state = initState;

  return {
    transit: function transit(nextState) {
      // eslint-disable-line

      state = nextState;

      if (state === HoverState.Finish) {
        onFinish();
      }
    },
    is: function is(st) {
      return st === state;
    },


    name: name
  };
};

function forEachHook(hooks, action) {
  if (!hooks) {
    return;
  }

  var hookNames = Object.keys(hooks);
  hookNames.forEach(function (hookName) {
    var eventName = 'mouse' + hookName;
    if (action === 'install') {
      window.addEventListener(eventName, hooks[hookName], true);
    } else if (action === 'uninstall') {
      window.removeEventListener(eventName, hooks[hookName], true);
    }
  });
}

function makeRecognizer(state, options) {
  var recognizer = _extends({}, options, {
    destroy: function destroy() {
      if (!state.is(HoverState.Finish)) {
        // eslint-disable-line
        forEachHook(recognizer.global, 'uninstall');
      }
    }
  });

  forEachHook(recognizer.global, 'install');
  return recognizer;
}

/**
 * 进入和离开的识别是独立的recognizer，每个recognizer可以绑定任意`onmouse***`事件。
 * 组件内部只需要提供识别完成后的回掉函数，不需要知道recognizer的细节。
 *
 * local下的事件是直接绑定在trigger上的
 * global下的事件是绑定在window上的capture事件
 */

/**
 * 进入状态的识别
 */
function makeHoverEnterRecognizer(_ref) {
  var enterDelay = _ref.enterDelay,
      onEnter = _ref.onEnter;

  var state = makeState('enter', onEnter);
  var timerId = void 0;

  var recognizer = makeRecognizer(state, {
    local: {
      enter: function enter() {
        state.transit(HoverState.Pending);

        timerId = setTimeout(function () {
          state.transit(HoverState.Finish);
          forEachHook(recognizer.global, 'uninstall');
        }, enterDelay);
      },
      leave: function leave() {
        if (timerId) {
          clearTimeout(timerId);
          timerId = undefined;

          state.transit(HoverState.Init);
        }
      }
    }
  });

  return recognizer;
}

/**
 * 离开状态的识别
 */
function makeHoverLeaveRecognizer(_ref2) {
  var leaveDelay = _ref2.leaveDelay,
      onLeave = _ref2.onLeave,
      isOutSide = _ref2.isOutSide;

  var state = makeState('leave', onLeave);
  var timerId = void 0;

  var recognizer = makeRecognizer(state, {
    global: {
      move: function move(evt) {
        var target = evt.target;


        if (isOutSide(target)) {
          if (!state.is(HoverState.Init)) {
            return;
          }

          state.transit(HoverState.Pending);

          timerId = setTimeout(function () {
            state.transit(HoverState.Finish);
            forEachHook(recognizer.global, 'uninstall');
          }, leaveDelay);
        } else {
          if (!state.is(HoverState.Pending)) {
            return;
          }

          if (timerId) {
            clearTimeout(timerId);
            timerId = undefined;

            state.transit(HoverState.Init);
          }
        }
      }
    }
  });

  return recognizer;
}

function callHook(recognizer, namespace, hookName) {
  var ns = recognizer && recognizer[namespace];

  for (var _len = arguments.length, args = Array(_len > 3 ? _len - 3 : 0), _key = 3; _key < _len; _key++) {
    args[_key - 3] = arguments[_key];
  }

  if (ns && ns[hookName]) ns[hookName].apply(ns, args);
}

function destroyRecognizer(recognizer) {
  if (recognizer) {
    recognizer.destroy();
  }
}

var PopoverHoverTrigger = (_temp2 = _class = function (_Trigger) {
  _inherits(PopoverHoverTrigger, _Trigger);

  function PopoverHoverTrigger() {
    var _ref3;

    var _temp, _this, _ret;

    _classCallCheck(this, PopoverHoverTrigger);

    for (var _len2 = arguments.length, args = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref3 = PopoverHoverTrigger.__proto__ || Object.getPrototypeOf(PopoverHoverTrigger)).call.apply(_ref3, [this].concat(args))), _this), _this.open = function () {
      _this.props.open();
    }, _this.close = function () {
      _this.props.close();
    }, _this.state = {
      enterRecognizer: _this.makeEnterRecognizer(),
      leaveRecognizer: null
    }, _this.isOutSide = function (node) {
      var _this$props = _this.props,
          getTriggerNode = _this$props.getTriggerNode,
          getContentNode = _this$props.getContentNode,
          isOutside = _this$props.isOutside;


      if (isOutside && isOutside(node)) {
        return true;
      }

      var contentNode = getContentNode();
      var triggerNode = getTriggerNode();

      if (contentNode && contentNode.contains(node) || triggerNode && triggerNode.contains(node)) {
        return false;
      }

      return true;
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  _createClass(PopoverHoverTrigger, [{
    key: 'makeEnterRecognizer',
    value: function makeEnterRecognizer() {
      return makeHoverEnterRecognizer({
        enterDelay: this.props.showDelay,
        onEnter: this.open
      });
    }
  }, {
    key: 'makeLeaveRecognizer',
    value: function makeLeaveRecognizer() {
      return makeHoverLeaveRecognizer({
        leaveDelay: this.props.hideDelay,
        onLeave: this.close,
        isOutSide: this.isOutSide
      });
    }
  }, {
    key: 'getTriggerProps',
    value: function getTriggerProps(child) {
      var _this2 = this;

      var _state = this.state,
          enterRecognizer = _state.enterRecognizer,
          leaveRecognizer = _state.leaveRecognizer;

      var enterHooks = enterRecognizer && enterRecognizer.local || {};
      var leaveHooks = leaveRecognizer && leaveRecognizer.local || {};
      var eventNames = (0, _uniq2['default'])([].concat(Object.keys(enterHooks), Object.keys(leaveHooks))).map(function (name) {
        return 'onMouse' + (0, _capitalize2['default'])(name);
      });
      var eventNameToHookName = function eventNameToHookName(eventName) {
        return eventName.slice('onMouse'.length).toLowerCase();
      };

      return eventNames.reduce(function (events, evtName) {
        var hookName = eventNameToHookName(evtName);
        events[evtName] = function (evt) {
          callHook(enterRecognizer, 'local', hookName);
          callHook(leaveRecognizer, 'local', hookName);

          _this2.triggerEvent(child, evtName, evt);
        };

        return events;
      }, {});
    }
  }, {
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(nextProps) {
      var contentVisible = nextProps.contentVisible;

      // visibility changed, create new recognizers

      if (contentVisible !== this.props.contentVisible) {
        // ensure global events are removed
        destroyRecognizer(this.state.enterRecognizer);
        destroyRecognizer(this.state.leaveRecognizer);

        this.setState({
          enterRecognizer: contentVisible ? null : this.makeEnterRecognizer(),
          leaveRecognizer: contentVisible ? this.makeLeaveRecognizer() : null
        });
      }
    }
  }]);

  return PopoverHoverTrigger;
}(_Trigger3['default']), _class.propTypes = _extends({}, _Trigger2.PopoverTriggerPropTypes, {

  showDelay: _react.PropTypes.number,
  hideDelay: _react.PropTypes.number,

  isOutside: _react.PropTypes.func
}), _class.defaultProps = {
  showDelay: 150,
  hideDelay: 150
}, _temp2);
exports['default'] = PopoverHoverTrigger;
module.exports = exports['default'];